@@ -30,7 +30,12 @@ import ansiblelint.utils
 from ansiblelint.app import App, get_app
 from ansiblelint.constants import States
 from ansiblelint.errors import LintWarning, MatchError, WarnSource
-from ansiblelint.file_utils import Lintable, expand_dirs_in_lintables
+from ansiblelint.file_utils import (
+    Lintable,
+    expand_dirs_in_lintables,
+    expand_paths_vars,
+    normpath,
+)
 from ansiblelint.logger import timed_info
 from ansiblelint.rules.syntax_check import OUTPUT_PATTERNS
 from ansiblelint.text import strip_ansi_escape
@@ -111,7 +116,7 @@ class Runner:
     def _update_exclude_paths(self, exclude_paths: list[str]) -> None:
         if exclude_paths:
             # These will be (potentially) relative paths
-            paths = ansiblelint.file_utils.expand_paths_vars(exclude_paths)
+            paths = expand_paths_vars(exclude_paths)
             # Since ansiblelint.utils.find_children returns absolute paths,
             # and the list of files we create in `Runner.run` can contain both
             # relative and absolute paths, we need to cover both bases.
@@ -169,7 +174,6 @@ class Runner:
                 if warn.category is DeprecationWarning:
                     continue
                 if warn.category is LintWarning:
-                    filename: None | Lintable = None
                     if isinstance(warn.source, WarnSource):
                         match = MatchError(
                             message=warn.source.message or warn.category.__name__,
@@ -179,13 +183,12 @@ class Runner:
                             lineno=warn.source.lineno,
                         )
                     else:
-                        filename = warn.source
                         match = MatchError(
                             message=(
                                 warn.message if isinstance(warn.message, str) else "?"
                             ),
                             rule=self.rules["warning"],
-                            lintable=Lintable(str(filename)),
+                            lintable=Lintable(str(warn.source)),
                         )
                     matches.append(match)
                     continue
@@ -277,7 +280,7 @@ class Runner:
                 continue
             _logger.debug(
                 "Examining %s of type %s",
-                ansiblelint.file_utils.normpath(file.path),
+                normpath(file.path),
                 file.kind,
             )
 
@@ -330,6 +333,7 @@ class Runner:
                     mode="w",
                     suffix=".yml",
                     prefix="play",
+                    encoding="utf-8",
                 )
                 fh.write(playbook_text)
                 fh.flush()
@@ -341,8 +345,6 @@ class Runner:
             # [WARNING]: provided hosts list is empty, only localhost is available. Note that the implicit localhost does not match 'all'
             cmd = [
                 "ansible-playbook",
-                "-i",
-                "localhost,",
                 "--syntax-check",
                 playbook_path,
             ]
@@ -498,7 +500,7 @@ class Runner:
                 playbook_ds = ansiblelint.utils.parse_yaml_from_file(str(lintable.path))
             except AnsibleError as exc:
                 msg = f"Loading {lintable.filename} caused an {type(exc).__name__} exception: {exc}, file was ignored."
-                logging.exception(msg)
+                _logger.exception(msg)
                 return []
         results = []
         # playbook_ds can be an AnsibleUnicode string, which we consider invalid
@@ -595,6 +597,7 @@ class Runner:
         examples.file = NamedTemporaryFile(  # noqa: SIM115
             mode="w+",
             suffix=f"_{lintable.path.name}.yaml",
+            encoding="utf-8",
         )
         examples.file.write(content)
         examples.file.flush()
